#########################################################################
#
# KDevPlatform Configuration File 
#
# This file sets various CMake Variables
#
# KDEVPLATFORM_INCLUDE_DIR             - The Include Directory for all KDEVPLATFORM libraries
# KDEVPLATFORM_INTERFACES_LIBRARY      - the interfaces library
# KDEVPLATFORM_LANGUAGE_LIBRARY        - the language library
# KDEVPLATFORM_OUTPUTVIEW_LIBRARY      - the outputview library
# KDEVPLATFORM_PROJECT_LIBRARY         - the project library
# KDEVPLATFORM_SUBLIME_LIBRARY         - the sublime library
# KDEVPLATFORM_SHELL_LIBRARY           - the shell library
# KDEVPLATFORM_TESTS_LIBRARY           - the tests library
# KDEVPLATFORM_UTIL_LIBRARY            - the util library
# KDEVPLATFORM_VCS_LIBRARY             - the vcs library
# KDEVPLATFORM_VERITAS                 - the veritas library
# KDEVPLATFORM_SOURCEFORMATTER_LIBRARY - the sourceformatter library
# KDEVPLATFORM_DEBUGGER_LIBRARY        - debugger module library
#
# Copyright 2008  Andreas Pakulat <apaku@gmx.de>
# Redistribution and use is allowed according to the terms of the BSD license.
######################################################################

get_filename_component(_KDEVPLATFORM_CURRENT_DIR  "${CMAKE_CURRENT_LIST_FILE}" PATH)

if(NOT WIN32)
# This is needed on non-win32 platforms, as lib-install-dir might be in a 
# totally different prefix than include-install-dir. So instead hardcode the
# absolute path during buildtime
set( KDEVPLATFORM_INCLUDE_DIR "/usr/include/kde4/kdevplatform" )

else(NOT WIN32)

set( KDEVPLATFORM_INCLUDE_DIR "${_KDEVPLATFORM_CURRENT_DIR}/../../../include/kdevplatform" )

endif(NOT WIN32)

if( NOT TARGET kdevplatforminterfaces )
    include("${_KDEVPLATFORM_CURRENT_DIR}/KDevPlatformTargets.cmake")
endif( NOT TARGET kdevplatforminterfaces )

macro( _kdevplatform_set_lib_vars _prefix _lib )
  set( KDEVPLATFORM_${_prefix}_LIBRARY ${_lib} )
endmacro( _kdevplatform_set_lib_vars )

_kdevplatform_set_lib_vars( INTERFACES kdevplatforminterfaces )
_kdevplatform_set_lib_vars( PROJECT kdevplatformproject )
_kdevplatform_set_lib_vars( LANGUAGE kdevplatformlanguage )
_kdevplatform_set_lib_vars( UTIL kdevplatformutil ) 
_kdevplatform_set_lib_vars( SHELL kdevplatformshell )
_kdevplatform_set_lib_vars( SUBLIME sublime )
_kdevplatform_set_lib_vars( VERITAS kdevplatformveritas )
_kdevplatform_set_lib_vars( VCS kdevplatformvcs )
_kdevplatform_set_lib_vars( OUTPUTVIEW kdevplatformoutputview )
_kdevplatform_set_lib_vars( SOURCEFORMATTER kdevplatformsourceformatter )
_kdevplatform_set_lib_vars( DEBUGGER kdevplatformdebugger )
_kdevplatform_set_lib_vars( TESTS kdevplatformtests )

include(${_KDEVPLATFORM_CURRENT_DIR}/KDevPlatformMacros.cmake)

mark_as_advanced(
    KDEVPLATFORM_INTERFACES_LIBRARY
    KDEVPLATFORM_LANGUAGE_LIBRARY
    KDEVPLATFORM_OUTPUTVIEW_LIBRARY
    KDEVPLATFORM_PROJECT_LIBRARY
    KDEVPLATFORM_SUBLIME_LIBRARY
    KDEVPLATFORM_SHELL_LIBRARY
    KDEVPLATFORM_UTIL_LIBRARY
    KDEVPLATFORM_VCS_LIBRARY
    KDEVPLATFORM_VERITAS_LIBRARY
    KDEVPLATFORM_SOURCEFORMATTER_LIBRARY
    KDEVPLATFORM_DEBUGGER_LIBRARY
    KDEVPLATFORM_TESTS_LIBRARY
)
